Package: EDIRquery
Title: Query the EDIR Database For Specific Gene
Version: 1.12.0
Authors@R: 
    person("Laura D.T.", "Vo Ngoc", , "doan.vongoc@vub.be", 
            role = c("aut", "cre"), comment = c(ORCID = "0000-0002-1597-900X"))
Description: EDIRquery provides a tool to search for genes of interest within the Exome Database of Interspersed Repeats (EDIR). A gene name is a required input, and users can additionally specify repeat sequence lengths, minimum and maximum distance between sequences, and whether to allow a 1-bp mismatch. Outputs include a summary of results by repeat length, as well as a dataframe of query results. Example data provided includes a subset of the data for the gene GAA (ENSG00000171298). To query the full database requires providing a path to the downloaded database files as a parameter.
License: GPL-3
Encoding: UTF-8
biocViews: Genetics, SequenceMatching
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Depends: R (>= 4.2.0)
Imports: tibble (>= 3.1.6), tictoc (>= 1.0.1), utils (>= 4.1.3), stats
        (>= 4.1.3), readr (>= 2.1.2), InteractionSet (>= 1.22.0),
        GenomicRanges (>= 1.46.1)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/EDIRquery
git_branch: RELEASE_3_23
git_last_commit: f93b460
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:53:58 UTC; biocbuild
Author: Laura D.T. Vo Ngoc [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1597-900X>)
Maintainer: Laura D.T. Vo Ngoc <doan.vongoc@vub.be>
