#' Gene chromosome location
#'
#' A dataset containing two formats of gene names and associated
#' chromosome number.
#'
#' @format A data frame with 60571 rows and 3 variables:
#' \describe{
#'   \item{chromosome_name}{chromosome}
#'   \item{ensembl_gene_id}{Ensembl gene ID of gene}
#'   \item{hgnc_symbol}{HGNC symbol of gene}
#' }

"gene_chr"
